@@ -2,13 +2,13 @@ import json
 import requests
 
 import openai_proxy
-
+from openai_proxy.utils import token_estimator
 
 def authenticate():
-    if openai_proxy.username == "" \
-            or openai_proxy.course_id == "" \
-            or openai_proxy.access_key == "" \
-            or openai_proxy.access_token == "":
+    if openai_proxy.username == "" or openai_proxy.username is None \
+            or openai_proxy.course_id == "" or openai_proxy.course_id is None\
+            or openai_proxy.access_key == "" or openai_proxy.access_key is None\
+            or openai_proxy.access_token == "" or openai_proxy.access_token is None:
         return "Please set your username, courseId, accessKey, and accessToken"
     return False
 
@@ -51,4 +51,20 @@ class Completion:
         else:
             return response['error']
 
+    @staticmethod
+    def price(prompt,
+               engine="babbage",
+               max_tokens=200,
+               n=1
+               ):
 
+        body = {
+            "prompt": prompt,
+            "max_tokens": max_tokens,
+            "engine": engine,
+            "n": n
+        }
+
+        return {
+            "price": token_estimator.price_calculator(body)
+        }
